@@ -415,6 +415,9 @@ class _ScopeVisitor(object):
         level = 0
         if node.level:
             level = node.level
+        if node.module is None and len(node.names) > 0: #Relative import "."
+            self._Import(node)
+            return
         imported_module = pynames.ImportedModule(self.get_module(),
                                                  node.module, level)
         if self._is_ignored_import(imported_module):
